pub struct BruteForceStore { /* private fields */ }Expand description
Pure‑Rust brute‑force vector store backed by MessagePack on disk.
Enabled by the internal feature (on by default).
Implementations
Sourceimpl BruteForceStore
impl BruteForceStore
Sourcepub fn open_or_create(folder: &Path) -> Result<BruteForceStore>
pub fn open_or_create(folder: &Path) -> Result<BruteForceStore>
Open an existing store or create a new one with the default RRF ranker.
Sourcepub fn open_or_create_with_ranker(
folder: &Path,
ranker: Box<dyn Ranker>,
) -> Result<BruteForceStore>
pub fn open_or_create_with_ranker( folder: &Path, ranker: Box<dyn Ranker>, ) -> Result<BruteForceStore>
Open an existing store or create a new one with a custom ranker.