BruteForceStore

Struct BruteForceStore 

pub struct BruteForceStore { /* private fields */ }
Pure‑Rust brute‑force vector store backed by MessagePack on disk. Enabled by the internal feature (on by default).

Implementations

Source

impl BruteForceStore

pub fn open_or_create(folder: &Path) -> Result<BruteForceStore>

Open an existing store or create a new one with the default RRF ranker.

pub fn open_or_create_with_ranker( folder: &Path, ranker: Box<dyn Ranker>, ) -> Result<BruteForceStore>

Open an existing store or create a new one with a custom ranker.

pub fn save(&self) -> Result<()>

Serialise the current state to the on‑disk MessagePack file.

pub fn flush(&self) -> Result<()>

Persist in-memory changes to disk if the store is dirty.

No-op when nothing has changed since the last save or flush. Called automatically on Drop.